## 2018 ESA PECS Course (Slovakia)
## Authors: Amalia Castro Gomez (ESA/ESRIN) and Pierre Louis Frison (University of Paris-Est)
## Date: August 2018
## Description:Explore the time series of different pixels

#library(raster)

#setwd("/home/rus/Desktop/shared/PECS_Slovakia/LandCover/outputs_backup/Step5_NDVI_backup/")
#pathdir<- getwd()


r <- brick("Step8_RasterStack.grd")
df4 <- read.csv(file="Step7_dataframe_df4.csv", header = TRUE, sep=",", stringsAsFactors = FALSE)
df4$date <-as.Date((df4$date))

## Previous to the course, in SNAP we visually identified
## two pixels (Affected and Non-Affected). Here below we entere their coordinates

#Coordinates of Affected pixel in UTM
xa <- 412934.98 #(easting)
ya <- 5444205.02 #(northing)

# Coordinates of Non Affected pixel in UTM
xn <- 414434.95 #(easting)
yn <- 5445225.00 #(northing)

# Plot both points over the maps
plot(r[[1]], main="2013-05-19 Affected (red) and NonAffected (blue) pixels")
points(xa,ya, col="red")
points(xn,yn, col="blue")

plot(r[[21]], main="2018-07-12 Affected (red) and NonAffected (blue) pixels")
points(xa,ya, col="red")
points(xn,yn, col="blue")


## Plot the time series of both pixels
affected <-matrix(data=c(xa, ya), nrow=1, dimnames=list(NULL,c('x','y')))
affectedCell <-cellFromXY(r,affected) 
affectedCell # 39284

NonAffected <-matrix(data=c(xn, yn), nrow=1, dimnames=list(NULL,c('x','y')))
NonAffectedCell <-cellFromXY(r,NonAffected) # 24608
NonAffectedCell # 25342

ts <- data.frame(sensor = df4$sensor,
                 date = df4$date,
                 affected = t(r[affectedCell]),
                 NonAffected = t(r[NonAffectedCell])
)

plot(ts$date, ts$affected, xlab='date', ylab='NDVI', type="l", ylim=c(0,1),main = "NDVI time series of Affected pixel")
plot(ts$date, ts$NonAffected, xlab='date', ylab='NDVI', type="l", ylim=c(0,1),main = "NDVI time series Non Affected pixel")


## Visualize the Time Series of other pixels in a dynamic way
plot(r[[21]],main="Plot of raster layer number 21")
x <- click() # Click somewhere on the plot
xCell <- cellFromXY(r,x)
tsx <- data.frame(sensor = df4$sensor,
  date = df4$date,
  xpix = t(r[xCell])
)
plot(tsx$date, tsx$xpix, xlab='date', ylab='NDVI', 
     type="l", ylim=c(0,1),main = "NDVI time series of pixel you clicked")


## Additional steps

## Zoom in the plot
# Plot both points over the maps
plot(r[[1]], main="2013-05-19 Affected (red) and NonAffected (blue) pixels")
points(xa,ya, col="red")
points(xn,yn, col="blue")

# Imagine a bounding box around the 2 points. 
# Click on its top left corner
corner1 <- click() 
# Click on its bottom right corner
corner2 <- click() # Same for the other corner

plot(r[[1]], main="2013-05-19 zoom",
     xlim = c(corner1[1], corner2[1]),
     ylim = c(corner2[2], corner1[2]))
points(xa,ya, col="red")
points(xn,yn, col="blue")

plot(r[[21]], main="2018-07-12 zoom",
     xlim = c(corner1[1], corner2[1]),
     ylim = c(corner2[2], corner1[2]))
points(xa,ya, col="red")
points(xn,yn, col="blue")

